@@ -1,7 +1,12 @@
-package Search::Elasticsearch::Client::1_0::Direct::Cat;
-$Search::Elasticsearch::Client::1_0::Direct::Cat::VERSION = '6.80_01'; # TRIAL
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
 
-$Search::Elasticsearch::Client::1_0::Direct::Cat::VERSION = '6.8001';use Moo;
+package Search::Elasticsearch::Client::1_0::Direct::Cat;
+$Search::Elasticsearch::Client::1_0::Direct::Cat::VERSION = '7.30_1'; # TRIAL
+
+$Search::Elasticsearch::Client::1_0::Direct::Cat::VERSION = '7.301';
+use Moo;
 with 'Search::Elasticsearch::Client::1_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
@@ -29,7 +34,7 @@ Search::Elasticsearch::Client::1_0::Direct::Cat - A client for running cat debug
 
 =head1 VERSION
 
-version 6.80_01
+version 7.30_1
 
 =head1 DESCRIPTION
 
