@@ -1,7 +1,12 @@
-package Search::Elasticsearch::Client::1_0::Direct::Indices;
-$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '6.80_01'; # TRIAL
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
 
-$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '6.8001';use Moo;
+package Search::Elasticsearch::Client::1_0::Direct::Indices;
+$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '7.30_1'; # TRIAL
+
+$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '7.301';
+use Moo;
 with 'Search::Elasticsearch::Client::1_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
@@ -18,7 +23,7 @@ Search::Elasticsearch::Client::1_0::Direct::Indices - A client for running index
 
 =head1 VERSION
 
-version 6.80_01
+version 7.30_1
 
 =head1 DESCRIPTION
 
