@@ -1,7 +1,12 @@
-package Search::Elasticsearch::Client::1_0::Scroll;
-$Search::Elasticsearch::Client::1_0::Scroll::VERSION = '6.80_01'; # TRIAL
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
 
-$Search::Elasticsearch::Client::1_0::Scroll::VERSION = '6.8001';use Moo;
+package Search::Elasticsearch::Client::1_0::Scroll;
+$Search::Elasticsearch::Client::1_0::Scroll::VERSION = '7.30_1'; # TRIAL
+
+$Search::Elasticsearch::Client::1_0::Scroll::VERSION = '7.301';
+use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
 
@@ -127,7 +132,7 @@ Search::Elasticsearch::Client::1_0::Scroll - A helper module for scrolled search
 
 =head1 VERSION
 
-version 6.80_01
+version 7.30_1
 
 =head1 SYNOPSIS
 
