@@ -1,7 +1,12 @@
-package Search::Elasticsearch::Client::1_0::TestServer;
-$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '6.80_01'; # TRIAL
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
 
-$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '6.8001';use strict;
+package Search::Elasticsearch::Client::1_0::TestServer;
+$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '7.30_1'; # TRIAL
+
+$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '7.301';
+use strict;
 use warnings;
 
 #===================================
@@ -43,7 +48,7 @@ Search::Elasticsearch::Client::1_0::TestServer - Client-specific backend for Sea
 
 =head1 VERSION
 
-version 6.80_01
+version 7.30_1
 
 =head1 AUTHOR
 
